package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 6, 2024
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Host string `env:"HOST, required"`
Port string `env:"PORT, default=5432"`
Username string `env:"USER, required"`
Password string `env:"PASSWORD, required"`
Database string `env:"DB, default=folioforge"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.